@@ -301,7 +301,7 @@ instance_init(LassoIdentity *identity)
 }
 
 static void
-class_init(LassoIdentityClass *klass)
+class_init(LassoIdentityClass *klass, void *unused G_GNUC_UNUSED)
 {
 	parent_class = g_type_class_peek_parent(klass);
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
