@@ -326,6 +326,7 @@ lasso_provider_get_first_http_method(LassoProvider *provider,
 	const gchar *role_prefix;
 
 	g_return_val_if_fail(LASSO_IS_PROVIDER(provider), LASSO_HTTP_METHOD_NONE);
+	g_return_val_if_fail(remote_provider != NULL, LASSO_HTTP_METHOD_NONE);
 	if (provider->private_data->conformance == LASSO_PROTOCOL_SAML_2_0) {
 		return lasso_saml20_provider_get_first_http_method(
 				provider, remote_provider, protocol_type);
@@ -870,6 +871,9 @@ dispose(GObject *object)
 	provider->private_data->affiliation_owner_id = NULL;
 	lasso_release_list_of_full(provider->private_data->endpoints, lasso_endpoint_free);
 
+	lasso_assign_new_signature_context(provider->private_data->signature_context,
+			LASSO_SIGNATURE_CONTEXT_NONE);
+
 	G_OBJECT_CLASS(parent_class)->dispose(G_OBJECT(provider));
 }
 
@@ -908,7 +912,7 @@ instance_init(LassoProvider *provider)
 }
 
 static void
-class_init(LassoProviderClass *klass)
+class_init(LassoProviderClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
@@ -965,6 +969,32 @@ lasso_provider_get_protocol_conformance(const LassoProvider *provider)
 	return provider->private_data->conformance;
 }
 
+/**
+ * lasso_provider_set_protocol_conformance:
+ * @provider: a #LassoProvider object
+ * @protocol_conformance: #LassoProtocolConformance enumerated value.
+ *
+ * Normally the protocol conformance is set when the metadata for the
+ * provider is loaded because the metadata defines the type of
+ * server. However some #LassoServer variants do not have metadata
+ * (e.g. ECP) therefore instead of loading the metadata it is
+ * necessary to explicitly set the protocol conformance because parts
+ * of the Lasso library dispatch based on the protocol conformance.
+ * Without the protocol conformance being set it is likely the wrong
+ * code will execute.
+ *
+ * **WARNING**, do not manually set the protocol conformance if
+ * metadata has been loaded, metadata is the final arbiter of protocol
+ * conformance.
+ *
+ * Return value: 0 on success; another value if an error occured.
+ **/
+void
+lasso_provider_set_protocol_conformance(LassoProvider *provider, LassoProtocolConformance protocol_conformance)
+{
+	provider->private_data->conformance = protocol_conformance;
+}
+
 gboolean
 _lasso_provider_load_metadata_from_buffer(LassoProvider *provider, const gchar *metadata, int length)
 {
@@ -1770,7 +1800,7 @@ lasso_provider_add_key(LassoProvider *provider, LassoKey *key, gboolean after)
 	LassoSignatureContext context;
 	lasso_error_t rc = 0;
 	GList **list = NULL;
-	xmlSecKey *xml_sec_key;
+	xmlSecKey *xml_sec_key = NULL;
 
 	lasso_bad_param(PROVIDER, provider);
 	lasso_bad_param(KEY, key);
@@ -1804,7 +1834,7 @@ lasso_provider_set_server_signing_key(LassoProvider *provider,
 		LassoKey *key)
 {
 	lasso_error_t rc = 0;
-	LassoSignatureContext context = LASSO_SIGNATURE_CONTEXT_NONE;
+	LassoSignatureContext context;
 
 	lasso_bad_param(PROVIDER, provider);
 	lasso_bad_param(KEY, key);
