@@ -284,7 +284,7 @@ int
 lasso_saml20_profile_init_artifact_resolve(LassoProfile *profile,
 		LassoProviderRole remote_provider_role, const char *msg, LassoHttpMethod method)
 {
-	char **query_fields;
+	xmlChar **query_fields;
 	char *artifact_b64 = NULL;
 	xmlChar *provider_succinct_id_b64 = NULL;
 	char *provider_succinct_id[21];
@@ -296,14 +296,13 @@ lasso_saml20_profile_init_artifact_resolve(LassoProfile *profile,
 	unsigned short index_endpoint = 0;
 
 	if (method == LASSO_HTTP_METHOD_ARTIFACT_GET) {
-		query_fields = urlencoded_to_strings(msg);
+		query_fields = lasso_urlencoded_to_strings(msg);
 		for (i=0; query_fields[i]; i++) {
 			if (strncmp((char*)query_fields[i], LASSO_SAML2_FIELD_ARTIFACT "=", 8) == 0) {
-				lasso_assign_string(artifact_b64, query_fields[i]+8);
+				lasso_assign_string(artifact_b64, (char*)query_fields[i]+8);
 			}
-			xmlFree(query_fields[i]);
 		}
-		lasso_release(query_fields);
+		lasso_release_array_of_xml_strings(query_fields);
 		if (artifact_b64 == NULL) {
 			return LASSO_PROFILE_ERROR_MISSING_ARTIFACT;
 		}
@@ -399,6 +398,7 @@ lasso_saml20_profile_process_artifact_resolve(LassoProfile *profile, const char
 
 	switch (lasso_profile_get_signature_verify_hint(profile)) {
 		case LASSO_PROFILE_SIGNATURE_VERIFY_HINT_MAYBE:
+		case LASSO_PROFILE_SIGNATURE_VERIFY_HINT_FORCE:
 			rc = profile->signature_status;
 			break;
 		case LASSO_PROFILE_SIGNATURE_VERIFY_HINT_IGNORE:
@@ -968,7 +968,15 @@ lasso_saml20_profile_build_request_msg(LassoProfile *profile, const char *servic
 		made_url = url = get_url(provider, service, http_method_to_binding(method));
 	}
 
-	if (url) {
+
+	// Usage of the Destination attribute on a request is mandated only
+	// in "3.4.5.2" and "3.5.5.2" in saml-bindings-2.0-os for signed requests
+	// and is marked as optional in the XSD schema otherwise.
+	// PAOS is a special case because an SP does not select an IdP - ECP does
+	// it instead. Therefore, this attribute needs to be left unpopulated.
+	if (method == LASSO_HTTP_METHOD_PAOS) {
+		lasso_release_string(((LassoSamlp2RequestAbstract*)profile->request)->Destination);
+	} else if (url) {
 		lasso_assign_string(((LassoSamlp2RequestAbstract*)profile->request)->Destination,
 				url);
 	} else {
@@ -1560,6 +1568,7 @@ lasso_saml20_profile_process_soap_response_with_headers(LassoProfile *profile,
 			remote_provider, response_msg, "ID", LASSO_MESSAGE_FORMAT_SOAP);
 	switch (lasso_profile_get_signature_verify_hint(profile)) {
 		case LASSO_PROFILE_SIGNATURE_VERIFY_HINT_MAYBE:
+		case LASSO_PROFILE_SIGNATURE_VERIFY_HINT_FORCE:
 			rc = profile->signature_status;
 			break;
 		case LASSO_PROFILE_SIGNATURE_VERIFY_HINT_IGNORE:
