@@ -100,7 +100,7 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 /*****************************************************************************/
 
 static void
-class_init(LassoDiscoQueryResponseClass *class)
+class_init(LassoDiscoQueryResponseClass *class, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(class);
 
