@@ -135,7 +135,7 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 
 
 static void
-class_init(LassoDstModifyClass *klass)
+class_init(LassoDstModifyClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
