@@ -73,7 +73,7 @@ static LassoNodeClass *parent_class = NULL;
 
 
 static void
-class_init(LassoIdWsf2DiscoEndpointContextClass *klass)
+class_init(LassoIdWsf2DiscoEndpointContextClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
