@@ -71,7 +71,8 @@ instance_init(LassoIdWsf2DiscoSvcMDAssociationDeleteResponse *node)
 }
 
 static void
-class_init(LassoIdWsf2DiscoSvcMDAssociationDeleteResponseClass *klass)
+class_init(LassoIdWsf2DiscoSvcMDAssociationDeleteResponseClass *klass,
+	   void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
