@@ -70,7 +70,7 @@ instance_init(LassoIdWsf2DiscoSvcMDAssociationQuery *node)
 }
 
 static void
-class_init(LassoIdWsf2DiscoSvcMDAssociationQueryClass *klass)
+class_init(LassoIdWsf2DiscoSvcMDAssociationQueryClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
