@@ -74,7 +74,7 @@ instance_init(LassoIdWsf2DstRequest *node)
 }
 
 static void
-class_init(LassoIdWsf2DstRequestClass *klass)
+class_init(LassoIdWsf2DstRequestClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
