@@ -58,7 +58,7 @@ static LassoNodeClass *parent_class = NULL;
 /*****************************************************************************/
 
 static void
-class_init(LassoIdWsf2DstRefCreateResponseClass *klass)
+class_init(LassoIdWsf2DstRefCreateResponseClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
