@@ -74,7 +74,7 @@ static LassoNodeClass *parent_class = NULL;
 
 
 static void
-class_init(LassoIdWsf2DstRefModifyItemClass *klass)
+class_init(LassoIdWsf2DstRefModifyItemClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
