@@ -94,7 +94,7 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 
 
 static void
-class_init(LassoIdWsf2DstRefModifyResponseClass *klass)
+class_init(LassoIdWsf2DstRefModifyResponseClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
