@@ -75,7 +75,7 @@ instance_init(LassoIdWsf2DstRefQueryItem *node)
 }
 
 static void
-class_init(LassoIdWsf2DstRefQueryItemClass *klass)
+class_init(LassoIdWsf2DstRefQueryItemClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
