@@ -83,7 +83,7 @@ instance_init(LassoIdWsf2PsListMembersRequest *node)
 }
 
 static void
-class_init(LassoIdWsf2PsListMembersRequestClass *klass)
+class_init(LassoIdWsf2PsListMembersRequestClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
