@@ -83,7 +83,7 @@ static LassoNodeClass *parent_class = NULL;
 
 
 static void
-class_init(LassoIdWsf2PsObjectClass *klass)
+class_init(LassoIdWsf2PsObjectClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
