@@ -68,7 +68,7 @@ static LassoNodeClass *parent_class = NULL;
 
 
 static void
-class_init(LassoIdWsf2PsSetObjectInfoRequestClass *klass)
+class_init(LassoIdWsf2PsSetObjectInfoRequestClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
