@@ -72,7 +72,7 @@ static LassoNodeClass *parent_class = NULL;
 
 
 static void
-class_init(LassoIdWsf2PsTestMembershipRequestClass *klass)
+class_init(LassoIdWsf2PsTestMembershipRequestClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
