@@ -68,7 +68,7 @@ instance_init(LassoIdWsf2Sb2Timeout *node)
 }
 
 static void
-class_init(LassoIdWsf2Sb2TimeoutClass *klass)
+class_init(LassoIdWsf2Sb2TimeoutClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
