@@ -94,7 +94,7 @@ static LassoNodeClass *parent_class = NULL;
 
 
 static void
-class_init(LassoIdWsf2SubsSubscriptionClass *klass)
+class_init(LassoIdWsf2SubsSubscriptionClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
