@@ -77,7 +77,7 @@ static LassoNodeClass *parent_class = NULL;
 
 
 static void
-class_init(LassoIdWsf2UtilStatusClass *klass)
+class_init(LassoIdWsf2UtilStatusClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
