@@ -139,7 +139,8 @@ init_from_query(LassoNode *node, char **query_fields)
 
 
 static void
-class_init(LassoLibFederationTerminationNotificationClass *klass)
+class_init(LassoLibFederationTerminationNotificationClass *klass,
+	   void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
