@@ -69,7 +69,7 @@ static struct XmlSnippet schema_snippets[] = {
 
 
 static void
-class_init(LassoSaTransformClass *klass)
+class_init(LassoSaTransformClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
