@@ -16,8 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "../private.h"
@@ -47,9 +46,16 @@
 /* private methods                                                           */
 /*****************************************************************************/
 
+struct _LassoSaml2AttributeValuePrivate {
+	GHashTable *any_attributes;
+};
+
 static struct XmlSnippet schema_snippets[] = {
-	{ "", SNIPPET_LIST_NODES | SNIPPET_ALLOW_TEXT,
+	{ "any", SNIPPET_LIST_NODES | SNIPPET_ANY | SNIPPET_ALLOW_TEXT,
 		G_STRUCT_OFFSET(LassoSaml2AttributeValue, any), NULL, NULL, NULL},
+	{ "any_attributes", SNIPPET_ATTRIBUTE | SNIPPET_ANY | SNIPPET_PRIVATE,
+		G_STRUCT_OFFSET(struct _LassoSaml2AttributeValuePrivate, any_attributes), NULL,
+		NULL, NULL },
 	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
@@ -75,7 +81,7 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 }
 
 static void
-class_init(LassoSaml2AttributeValueClass *klass)
+class_init(LassoSaml2AttributeValueClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
@@ -85,6 +91,7 @@ class_init(LassoSaml2AttributeValueClass *klass)
 	lasso_node_class_set_nodename(nclass, "AttributeValue");
 	lasso_node_class_set_ns(nclass, LASSO_SAML2_ASSERTION_HREF, LASSO_SAML2_ASSERTION_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
+	g_type_class_add_private(klass, sizeof(struct _LassoSaml2AttributeValuePrivate));
 }
 
 GType
