@@ -75,7 +75,7 @@ static LassoNodeClass *parent_class = NULL;
 /*****************************************************************************/
 
 static void
-class_init(LassoSamlp2ExtensionsClass *klass)
+class_init(LassoSamlp2ExtensionsClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
