@@ -18,16 +18,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __LASSO_SOAP_BINDING_H__
 #define __LASSO_SOAP_BINDING_H__
 
-#include "./soap_binding_provider.h"
-#include "./soap_binding_correlation.h"
-#include "./soap-1.1/soap_envelope.h"
+#include "soap_binding_provider.h"
+#include "soap_binding_correlation.h"
+#include "soap-1.1/soap_envelope.h"
 
 #ifdef __cplusplus
 extern "C" {
